@@ -36,11 +36,12 @@ Notes
   from site to arrayand vice versa.
 """
 
-from datetime import datetime
 import copy
 import numpy as np
 
 from collections import OrderedDict
+from datetime import datetime
+from typing import Callable
 
 from pydarnio import borealis_exceptions
 
@@ -190,6 +191,9 @@ class BaseFormat():
     find_max_blanked_samples(records): int
         Find the max number of blanked samples between records in a site file,
         for restructuring to arrays.
+    find_max_pulse_phase_offset(records): list
+        Find the maximum shape of the phase encoding values between records in
+        a site style records file, for restructuring to arrays.
 
     Notes
     -----
@@ -901,9 +905,18 @@ class BaseFormat():
         # get array dims of the unshared fields arrays
         field_dimensions = {}
         for field in cls.unshared_fields():
-            dims = [dimension_function(data_dict) for
+            d = [dimension_function(data_dict) for
                     dimension_function in
                     cls.unshared_fields_dims_array()[field]]
+            
+            dims = []
+            for dim in d:
+                if isinstance(dim,list):
+                    for i in dim:
+                        dims.append(i)
+                else:
+                    dims.append(dim)
+
             field_dimensions[field] = dims
 
         # all fields to become arrays
@@ -915,6 +928,10 @@ class BaseFormat():
                 datatype = cls.single_element_types()[field]
             else:  # field in array_dtypes
                 datatype = cls.array_dtypes()[field]
+            if datatype == np.unicode_:
+                # unicode type needs to be explicitly set to have
+                # multiple chars (256)
+                datatype='|U256'
             empty_array = np.empty(array_dims, dtype=datatype)
             # initialize all values to NaN; some indices may not be filled
             # do to dimensions that are max values (num sequences, etc can
@@ -1017,6 +1034,15 @@ class BaseFormat():
                     site_dims = [dimension_function(data_dict, record_num)
                                  for dimension_function in
                                  cls.unshared_fields_dims_site()[field]]
+                    dims = []
+                    for dim in site_dims:
+                        if isinstance(dim,list):
+                            for i in dim:
+                                dims.append(i)
+                        else:
+                            dims.append(dim)
+                    
+                    site_dims = dims
                     index_slice = [slice(0, i) for i in site_dims]
                     index_slice.insert(0, record_num)
                     index_slice = tuple(index_slice)
@@ -1089,7 +1115,7 @@ class BaseFormat():
         return max_beams
 
     @staticmethod
-    def find_max_blanked_samples(records: OrderedDict) -> int:
+    def find_max_field_len_func(field_name: str) -> Callable:
         """
         Finds the maximum number of blanked samples between records in a
         Borealis site style records file.
@@ -1102,17 +1128,70 @@ class BaseFormat():
 
         Returns
         -------
-        max_beams
-            The largest number of beams found in one record from the
-            file
+        find_max_field_len
+            The function that returns the largest len() of the field in all
+            records
+        Notes
+        -----
+        Used by unshared_fields_array_dims functions for 'blanked_samples'
+        and 'slice_interfacing'.
+        The number of blanked_samples is a dimension of the per-record array.
+        """
+        def find_max_field_len(records: OrderedDict) -> int:
+            """
+            Finds the maximum number of a field between records in a
+            Borealis site style records file.
+            Parameters
+            ----------
+            records
+                Site formatted records from a Borealis file, organized as one
+                record for each slice
+            Returns
+            -------
+            max_field_len
+                The largest len() of the field in all records
+            """
+            max_field_len = 0
+            for k in records:
+                if max_field_len < len(records[k][field_name]):
+                    max_field_len = len(records[k][field_name])
+            return max_field_len
+
+        return find_max_field_len
+
+    
+    @staticmethod
+    def find_max_pulse_phase_offset(records: OrderedDict) -> int:
+        """
+        Finds the maximum shape of the phase encoding values between records
+        in a Borealis site style records file.
+
+        Parameters
+        ----------
+        records
+            Site formatted records from a Borealis file, organized as one
+            record for each slice
+
+        Returns
+        -------
+        max_ppo_shape
+            list of largest dimensions found in the records
 
         Notes
         -----
-        Used by unshared_fields_array_dims functions if the number of
-        blanked_samples is a dimension of the per-record array.
+        Used by the unshared_fields_array_dims functions if the number of
+        dimensions varies per record.
         """
-        max_blanked_samples = 0
+
+        first_key = list(records.keys())[0]
+        max_ppo_shape = records[first_key]["pulse_phase_offset"].shape
+        if max_ppo_shape[0] == 0:
+            return 0
+
         for k in records:
-            if max_blanked_samples < len(records[k]["blanked_samples"]):
-                max_blanked_samples = len(records[k]["blanked_samples"])
-        return max_blanked_samples
+            shape = records[k]["pulse_phase_offset"].shape
+            tmp = np.array([shape, max_ppo_shape])
+            max_ppo_shape = tmp.max(axis=0)        
+
+        return list(max_ppo_shape)
+
